bayespy.nodes.SwitchingGaussianMarkovChain.get_gradient
=======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.get_gradient